/**
 * Program IsCanvas.java
 * This program plots the spins.  A grid is drawn and spins are
 * labels red for up, green for down.  Very Christmasy.
 * This program can be separated from the main file.  Call it IsCanvas.java
 * and make the class file with javac IsCanvas.java.
 * Also, add "import java.awt.*;" as the first line (drop the quotes).
 **/

import java.awt.*;

class IsCanvas extends Canvas {
  
  int IsingX,IsingY;
  int ScaleX,ScaleY;
  double dw,dh;
  int w,h;
  IsLattice lattice;

  //Needed for double buffering the image.
  Dimension offDimension;
  Image offImage;
  Graphics offGraphics;

  //A constructor
  public IsCanvas(IsLattice lattice,int IsingX,int IsingY) {
    this.lattice=lattice;
    this.IsingX=IsingX;
    this.IsingY=IsingY;
  }

  //Another constructor
  public IsCanvas() {;}
    
  // Define the local paint method to draw the grid and color in the squares
  public void paint(Graphics g) {
    update(g);
  }

  public void update(Graphics g) {

    //Size of the window.  The size returned by the getSize() functions
    //is slightly smaller than the actual size used by the setSize() method
    //of Frame.  Thus, we have to scale the spacing to make a uniform
    //grid.

    w = getSize().width;
    h = getSize().height;
    ScaleX=IsingX/w;    
    ScaleY=IsingY/h;

    Dimension d=getSize();
    
    //Spacing between lines
    dw=(double)w/(double)(Ising2.XDIM);
    dh=(double)h/(double)(Ising2.YDIM);
    
    //Create the offscreen image
    if((offGraphics==null)
       ||(d.width!=offDimension.width)
       ||(d.height!=offDimension.height)){
      offDimension=d;
      offImage=createImage(d.width,d.height);
      offGraphics=offImage.getGraphics();
    }

    //Erase the previous image
    offGraphics.setColor(getBackground());
    offGraphics.fillRect(0,0,d.width,d.height);
    offGraphics.setColor(Color.black);
    
    //Fill in the squares.  Image is drawn in the background.
    for(int i=0;i<Ising2.XDIM;i++)
      for(int j=0;j<Ising2.YDIM;j++) {
	if(lattice.spins[i][j]==Ising2.SPIN_UP) {
	  offGraphics.setColor(Color.red);
	  offGraphics.fillRect(i*(int)dw,j*(int)dh,(i+1)*(int)dw,
			       (j+1)*(int)dh);
	}
	else {
	  offGraphics.clearRect(i*(int)dw,j*(int)dh,(i+1)*(int)dw,
				(j+1)*(int)dh);
	}
      }

    //Now draw the completed image on the canvas.
    g.drawImage(offImage,0,0,this);
  }

  //If we don't specify this, the canvas might not show up at all
  //(depending on the layout manager).
  public Dimension getMinimumSize() {
    return new Dimension(IsingX,IsingY);
  }
  
  //If we don't specify this, the canvas might not show up at all
  //(depending on the layout manager).
  public Dimension getPreferredSize() {
    return getMinimumSize();
  }
}
